@@ -377,7 +377,7 @@ images.add_command(get_similar_images)
     help="Subscription ID to use to license the image",
     type=str,
 )
-@click.option("--format", multiple=False, help="Image format", type=str)
+@click.option("--format", multiple=False, help="(Deprecated) Image format", type=str)
 @click.option("--size", multiple=False, help="Image size", type=str)
 @click.option(
     "--search-id",
